@@ -384,7 +384,7 @@ enum ZT_ResultCode
 	 */
 	ZT_RESULT_OK_IGNORED = 1,
 
-	// Fatal errors (>100, <1000)
+	// Fatal errors (>=100, <1000)
 
 	/**
 	 * Ran out of memory
@@ -1208,7 +1208,7 @@ typedef struct
 	bool ssoEnabled;
 
 	/**
-	 * SSO verison
+	 * SSO version
 	 */
 	uint64_t ssoVersion;
 
@@ -1246,6 +1246,11 @@ typedef struct
 	 * oidc client id
 	 */
 	char ssoClientID[256];
+
+	/**
+	 * sso provider
+	 **/
+	char ssoProvider[64];
 } ZT_VirtualNetworkConfig;
 
 /**
@@ -2066,7 +2071,7 @@ ZT_SDK_API int ZT_Node_sendUserMessage(ZT_Node *node,void *tptr,uint64_t dest,ui
  * NetworkConfigMaster base class in node/. No type checking is performed,
  * so a pointer to anything else will result in a crash.
  *
- * @param node ZertTier One node
+ * @param node ZeroTier One node
  * @param networkConfigMasterInstance Instance of NetworkConfigMaster C++ class or NULL to disable
  * @return OK (0) or error code if a fatal error condition has occurred
  */
